summaryrefslogtreecommitdiff
path: root/src/wx
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2013-04-14 00:48:34 +0100
committerCarl Hetherington <cth@carlh.net>2013-04-14 00:48:34 +0100
commitf90e90cdec39c7959c26e8199ee2170cedb4f256 (patch)
treef1a59bbc3c493faa9da6385246b34fd21b332014 /src/wx
parent7fb622a18582f18fcc6cfe140a262fd6cc8cad88 (diff)
parent7ee21d16c01b90c22192cd10f118419881fe504e (diff)
Merge branch 'content-rework-take5' of /home/carl/git/dvdomatic into content-rework-take5
Diffstat (limited to 'src/wx')
-rw-r--r--src/wx/audio_dialog.cc2
-rw-r--r--src/wx/config_dialog.cc6
-rw-r--r--src/wx/config_dialog.h4
-rw-r--r--src/wx/po/es_ES.po16
-rw-r--r--src/wx/po/fr_FR.po16
-rw-r--r--src/wx/po/it_IT.po16
-rw-r--r--src/wx/po/sv_SE.po18
-rw-r--r--src/wx/wscript12
-rw-r--r--src/wx/wx_util.cc2
9 files changed, 46 insertions, 46 deletions
diff --git a/src/wx/audio_dialog.cc b/src/wx/audio_dialog.cc
index bed7aac6d..15d746839 100644
--- a/src/wx/audio_dialog.cc
+++ b/src/wx/audio_dialog.cc
@@ -100,7 +100,7 @@ AudioDialog::set_film (shared_ptr<Film> f)
_film_changed_connection = _film->Changed.connect (bind (&AudioDialog::film_changed, this, _1));
_film_audio_analysis_succeeded_connection = _film->AudioAnalysisSucceeded.connect (bind (&AudioDialog::try_to_load_analysis, this));
- SetTitle (wxString::Format (_("DVD-o-matic audio - %s"), std_to_wx(_film->name()).data()));
+ SetTitle (wxString::Format (_("DCP-o-matic audio - %s"), std_to_wx(_film->name()).data()));
}
diff --git a/src/wx/config_dialog.h b/src/wx/config_dialog.h
index f6f3b3707..a2fc1f4b1 100644
--- a/src/wx/config_dialog.h
+++ b/src/wx/config_dialog.h
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.h
- * @brief A dialogue to edit DVD-o-matic configuration.
+ * @brief A dialogue to edit DCP-o-matic configuration.
*/
#include <wx/wx.h>
@@ -31,7 +31,7 @@ class DirPickerCtrl;
class ServerDescription;
/** @class ConfigDialog
- * @brief A dialogue to edit DVD-o-matic configuration.
+ * @brief A dialogue to edit DCP-o-matic configuration.
*/
class ConfigDialog : public wxDialog
{
diff --git a/src/wx/po/es_ES.po b/src/wx/po/es_ES.po
index 207708589..abb6b780f 100644
--- a/src/wx/po/es_ES.po
+++ b/src/wx/po/es_ES.po
@@ -5,7 +5,7 @@
#
msgid ""
msgstr ""
-"Project-Id-Version: libdvdomatic-wx\n"
+"Project-Id-Version: libdcpomatic-wx\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2013-04-09 11:14+0100\n"
"PO-Revision-Date: 2013-04-02 19:08-0500\n"
@@ -22,7 +22,7 @@ msgid "%"
msgstr "%"
#: src/wx/config_dialog.cc:61
-msgid "(restart DVD-o-matic to see language changes)"
+msgid "(restart DCP-o-matic to see language changes)"
msgstr ""
#: src/wx/film_editor.cc:1269
@@ -141,17 +141,17 @@ msgid "DCP Name"
msgstr "Nombre DCP"
#: src/wx/wx_util.cc:61
-msgid "DVD-o-matic"
-msgstr "DVD-o-matic"
+msgid "DCP-o-matic"
+msgstr "DCP-o-matic"
#: src/wx/config_dialog.cc:44
-msgid "DVD-o-matic Preferences"
-msgstr "Preferencias DVD-o-matic"
+msgid "DCP-o-matic Preferences"
+msgstr "Preferencias DCP-o-matic"
#: src/wx/audio_dialog.cc:101
#, fuzzy, c-format
-msgid "DVD-o-matic audio - %s"
-msgstr "Audio DVD-o-matic - %1"
+msgid "DCP-o-matic audio - %s"
+msgstr "Audio DCP-o-matic - %1"
#: src/wx/config_dialog.cc:102
msgid "Default DCI name details"
diff --git a/src/wx/po/fr_FR.po b/src/wx/po/fr_FR.po
index 80ee5dbfd..2aac7114c 100644
--- a/src/wx/po/fr_FR.po
+++ b/src/wx/po/fr_FR.po
@@ -5,7 +5,7 @@
#
msgid ""
msgstr ""
-"Project-Id-Version: DVD-o-matic FRENCH\n"
+"Project-Id-Version: DCP-o-matic FRENCH\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2013-04-09 11:14+0100\n"
"PO-Revision-Date: 2013-03-20 00:34+0100\n"
@@ -21,7 +21,7 @@ msgid "%"
msgstr "%"
#: src/wx/config_dialog.cc:61
-msgid "(restart DVD-o-matic to see language changes)"
+msgid "(restart DCP-o-matic to see language changes)"
msgstr ""
#: src/wx/film_editor.cc:1269
@@ -140,17 +140,17 @@ msgid "DCP Name"
msgstr "Nom du DCP"
#: src/wx/wx_util.cc:61
-msgid "DVD-o-matic"
-msgstr "DVD-o-matic"
+msgid "DCP-o-matic"
+msgstr "DCP-o-matic"
#: src/wx/config_dialog.cc:44
-msgid "DVD-o-matic Preferences"
-msgstr "Préférences DVD-o-matic"
+msgid "DCP-o-matic Preferences"
+msgstr "Préférences DCP-o-matic"
#: src/wx/audio_dialog.cc:101
#, c-format
-msgid "DVD-o-matic audio - %s"
-msgstr "Son DVD-o-matic - %s"
+msgid "DCP-o-matic audio - %s"
+msgstr "Son DCP-o-matic - %s"
#: src/wx/config_dialog.cc:102
msgid "Default DCI name details"
diff --git a/src/wx/po/it_IT.po b/src/wx/po/it_IT.po
index 78fd0dee9..7b06495e8 100644
--- a/src/wx/po/it_IT.po
+++ b/src/wx/po/it_IT.po
@@ -22,8 +22,8 @@ msgid "%"
msgstr "%"
#: src/wx/config_dialog.cc:61
-msgid "(restart DVD-o-matic to see language changes)"
-msgstr "(riavviare DVD-o-matic per vedere i cambiamenti di lingua)"
+msgid "(restart DCP-o-matic to see language changes)"
+msgstr "(riavviare DCP-o-matic per vedere i cambiamenti di lingua)"
#: src/wx/film_editor.cc:1269
msgid "1 channel"
@@ -141,17 +141,17 @@ msgid "DCP Name"
msgstr "Nome del DCP"
#: src/wx/wx_util.cc:61
-msgid "DVD-o-matic"
-msgstr "DVD-o-matic"
+msgid "DCP-o-matic"
+msgstr "DCP-o-matic"
#: src/wx/config_dialog.cc:44
-msgid "DVD-o-matic Preferences"
-msgstr "Preferenze DVD-o-matic"
+msgid "DCP-o-matic Preferences"
+msgstr "Preferenze DCP-o-matic"
#: src/wx/audio_dialog.cc:101
#, c-format
-msgid "DVD-o-matic audio - %s"
-msgstr "Audio DVD-o-matic - %s"
+msgid "DCP-o-matic audio - %s"
+msgstr "Audio DCP-o-matic - %s"
#: src/wx/config_dialog.cc:102
msgid "Default DCI name details"
diff --git a/src/wx/po/sv_SE.po b/src/wx/po/sv_SE.po
index e52589ff0..96fafadeb 100644
--- a/src/wx/po/sv_SE.po
+++ b/src/wx/po/sv_SE.po
@@ -5,7 +5,7 @@
#
msgid ""
msgstr ""
-"Project-Id-Version: DVD-o-matic\n"
+"Project-Id-Version: DCP-o-matic\n"
"Report-Msgid-Bugs-To: \n"
"POT-Creation-Date: 2013-04-09 11:14+0100\n"
"PO-Revision-Date: 2013-04-09 10:13+0100\n"
@@ -22,8 +22,8 @@ msgid "%"
msgstr "%"
#: src/wx/config_dialog.cc:61
-msgid "(restart DVD-o-matic to see language changes)"
-msgstr "(starta om DVD-o-matic för att se språkändringar)"
+msgid "(restart DCP-o-matic to see language changes)"
+msgstr "(starta om DCP-o-matic för att se språkändringar)"
#: src/wx/film_editor.cc:1269
msgid "1 channel"
@@ -141,17 +141,17 @@ msgid "DCP Name"
msgstr "DCP Namn"
#: src/wx/wx_util.cc:61
-msgid "DVD-o-matic"
-msgstr "DVD-o-matic"
+msgid "DCP-o-matic"
+msgstr "DCP-o-matic"
#: src/wx/config_dialog.cc:44
-msgid "DVD-o-matic Preferences"
-msgstr "DVD-o-matic Inställningar"
+msgid "DCP-o-matic Preferences"
+msgstr "DCP-o-matic Inställningar"
#: src/wx/audio_dialog.cc:101
#, c-format
-msgid "DVD-o-matic audio - %s"
-msgstr "DVD-o-matic audio - %s"
+msgid "DCP-o-matic audio - %s"
+msgstr "DCP-o-matic audio - %s"
#: src/wx/config_dialog.cc:102
msgid "Default DCI name details"
diff --git a/src/wx/wscript b/src/wx/wscript
index 7f9cde9ac..09bf40393 100644
--- a/src/wx/wscript
+++ b/src/wx/wscript
@@ -34,18 +34,18 @@ def build(bld):
else:
obj = bld(features = 'cxx cxxshlib')
- obj.name = 'libdvdomatic-wx'
+ obj.name = 'libdcpomatic-wx'
obj.includes = [ '..' ]
obj.export_includes = ['.']
obj.uselib = 'WXWIDGETS'
- obj.use = 'libdvdomatic'
+ obj.use = 'libdcpomatic'
obj.source = sources
- obj.target = 'dvdomatic-wx'
+ obj.target = 'dcpomatic-wx'
- i18n.po_to_mo(os.path.join('src', 'wx'), 'libdvdomatic-wx', bld)
+ i18n.po_to_mo(os.path.join('src', 'wx'), 'libdcpomatic-wx', bld)
def pot(bld):
- i18n.pot(os.path.join('src', 'wx'), sources, 'libdvdomatic-wx')
+ i18n.pot(os.path.join('src', 'wx'), sources, 'libdcpomatic-wx')
def pot_merge(bld):
- i18n.pot_merge(os.path.join('src', 'wx'), 'libdvdomatic-wx')
+ i18n.pot_merge(os.path.join('src', 'wx'), 'libdcpomatic-wx')
diff --git a/src/wx/wx_util.cc b/src/wx/wx_util.cc
index 720a058cb..3dad6e7fd 100644
--- a/src/wx/wx_util.cc
+++ b/src/wx/wx_util.cc
@@ -58,7 +58,7 @@ add_label_to_grid_bag_sizer (wxGridBagSizer* s, wxWindow* p, wxString t, wxGBPos
void
error_dialog (wxWindow* parent, wxString m)
{
- wxMessageDialog* d = new wxMessageDialog (parent, m, _("DVD-o-matic"), wxOK);
+ wxMessageDialog* d = new wxMessageDialog (parent, m, _("DCP-o-matic"), wxOK);
d->ShowModal ();
d->Destroy ();
}
diff --git a/src/wx/config_dialog.cc b/src/wx/config_dialog.cc
index 1d025f3fa..4ae8f1eb4 100644
--- a/src/wx/config_dialog.cc
+++ b/src/wx/config_dialog.cc
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.cc
* @brief A dialogue to edit DVD-o-matic configuration.
*/
#include <iostream>
@@ -41,7 +41,7 @@ using namespace std;
using boost::bind;
ConfigDialog::ConfigDialog (wxWindow* parent)
- : wxDialog (parent, wxID_ANY, _("DVD-o-matic Preferences"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
+ : wxDialog (parent, wxID_ANY, _("DCP-o-matic Preferences"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
{
wxFlexGridSizer* table = new wxFlexGridSizer (3, 6, 6);
table->AddGrowableCol (1, 1);
@@ -58,7 +58,7 @@ ConfigDialog::ConfigDialog (wxWindow* parent)
table->AddSpacer (0);
table->AddSpacer (0);
- wxStaticText* restart = add_label_to_sizer (table, this, _("(restart DVD-o-matic to see language changes)"));
+ wxStaticText* restart = add_label_to_sizer (table, this, _("(restart DCP-o-matic to see language changes)"));
wxFont font = restart->GetFont();
font.SetStyle (wxFONTSTYLE_ITALIC);
font.SetPointSize (font.GetPointSize() - 1);
@@ -18,7 +18,7 @@
*/
/** @file src/config_dialog.cc
- * @brief A dialogue to edit DVD-o-matic configuration.
+ * @brief A dialogue to edit DCP-o-matic configuration.
*/
#include <iostream>